"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const log = require("./log");
const db = require("./db");
const _1 = require("./_");
const Event_1 = require("./Event");
const ServiceItem_1 = require("./ServiceItem");
class Service {
    constructor() {
        this._items = [];
        this._load();
    }
    static get(id, serviceId) {
        return _1.default.service.get(id, serviceId);
    }
    static exists(id, serviceId) {
        return _1.default.service.exists(id, serviceId);
    }
    static findByChannel(channel) {
        return _1.default.service.findByChannel(channel);
    }
    static findByNetworkId(networkId) {
        return _1.default.service.findByNetworkId(networkId);
    }
    static findByNetworkIdWithLogoId(networkId, logoId) {
        return _1.default.service.findByNetworkIdWithLogoId(networkId, logoId);
    }
    static all() {
        return _1.default.service.items;
    }
    get items() {
        return this._items;
    }
    add(item) {
        if (this.get(item.id) !== null) {
            return;
        }
        this._items.push(item);
        Event_1.default.emit("service", "create", item.export());
        this.save();
    }
    get(id, serviceId) {
        if (serviceId === undefined) {
            const l = this._items.length;
            for (let i = 0; i < l; i++) {
                if (this._items[i].id === id) {
                    return this._items[i];
                }
            }
        }
        else {
            const l = this._items.length;
            for (let i = 0; i < l; i++) {
                if (this._items[i].networkId === id && this._items[i].serviceId === serviceId) {
                    return this._items[i];
                }
            }
        }
        return null;
    }
    exists(id, serviceId) {
        return this.get(id, serviceId) !== null;
    }
    findByChannel(channel) {
        const items = [];
        const l = this._items.length;
        for (let i = 0; i < l; i++) {
            if (this._items[i].channel === channel) {
                items.push(this._items[i]);
            }
        }
        return items;
    }
    findByNetworkId(networkId) {
        const items = [];
        const l = this._items.length;
        for (let i = 0; i < l; i++) {
            if (this._items[i].networkId === networkId) {
                items.push(this._items[i]);
            }
        }
        return items;
    }
    findByNetworkIdWithLogoId(networkId, logoId) {
        const items = [];
        const l = this._items.length;
        for (let i = 0; i < l; i++) {
            if (this._items[i].networkId === networkId && this._items[i].logoId === logoId) {
                items.push(this._items[i]);
            }
        }
        return items;
    }
    save() {
        clearTimeout(this._saveTimerId);
        this._saveTimerId = setTimeout(() => this._save(), 500);
    }
    _load() {
        log.debug("loading services...");
        let dropped = false;
        db.loadServices(_1.default.configIntegrity.channels).forEach(service => {
            const channelItem = _1.default.channel.get(service.channel.type, service.channel.channel);
            if (channelItem === null) {
                dropped = true;
                return;
            }
            if (service.networkId === undefined || service.serviceId === undefined) {
                dropped = true;
                return;
            }
            this.add(new ServiceItem_1.default(channelItem, service.networkId, service.serviceId, service.name, service.type, service.logoId, service.logoData, service.remoteControlKeyId, service.epgReady, service.epgUpdatedAt));
        });
        if (dropped) {
            this.save();
        }
    }
    _save() {
        log.debug("saving services...");
        db.saveServices(this._items.map(service => service.export(true)), _1.default.configIntegrity.channels);
    }
}
exports.default = Service;
//# sourceMappingURL=Service.js.map