"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.get = void 0;
const Service_1 = require("../../Service");
const get = (req, res) => {
    const apiRoot = `${req.protocol}://${req.headers.host}/api`;
    const services = [...Service_1.default.all()];
    services.sort((a, b) => a.getOrder() - b.getOrder());
    let m = `#EXTM3U url-tvg="${apiRoot}/iptv/xmltv"\n`;
    for (const service of services) {
        if (service.type !== 1) {
            continue;
        }
        m += `#EXTINF:-1 tvg-id="${service.id}"`;
        if (service.hasLogoData) {
            m += ` tvg-logo="${apiRoot}/services/${service.id}/logo"`;
        }
        m += ` group-title="${service.channel.type}",${service.name}\n`;
        m += `${apiRoot}/services/${service.id}/stream\n`;
    }
    res.setHeader("Content-Type", "application/x-mpegURL; charset=utf-8");
    res.status(200);
    res.end(m);
};
exports.get = get;
exports.get.apiDoc = {
    tags: ["iptv"],
    summary: "IPTV - M3U Playlist",
    produces: ["application/x-mpegURL"],
    responses: {
        200: {
            description: "OK"
        },
        default: {
            description: "Unexpected Error",
            schema: {
                $ref: "#/definitions/Error"
            }
        }
    }
};
//# sourceMappingURL=playlist.js.map