"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.get = exports.parameters = void 0;
const Service_1 = require("../../../Service");
exports.parameters = [
    {
        in: "path",
        name: "id",
        type: "integer",
        maximum: 6553565535,
        required: true
    }
];
const get = (req, res) => {
    const service = Service_1.default.get(req.params.id);
    if (service === null || service === undefined) {
        res.writeHead(404, "Not Found");
        res.end();
        return;
    }
    if (service.hasLogoData === false) {
        res.writeHead(503, "Logo Data Unavailable");
        res.end();
        return;
    }
    res.setHeader("Content-Type", "image/png");
    res.status(200);
    res.end(service.logoData);
};
exports.get = get;
exports.get.apiDoc = {
    tags: ["services"],
    operationId: "getLogoImage",
    produces: ["image/png"],
    responses: {
        200: {
            description: "OK"
        },
        404: {
            description: "Not Found"
        },
        503: {
            description: "Logo Data Unavailable"
        },
        default: {
            description: "Unexpected Error"
        }
    }
};
//# sourceMappingURL=logo.js.map